@@ -4,8 +4,8 @@ import hashlib
 import sys
 import requests
 import time
+import pkg_resources
 from packaging import version
-from auterioncli.version_util import get_version
 
 
 def eprint(*args, **kwargs):
@@ -76,7 +76,7 @@ def check_for_updates(persistent_state):
         data = res.json()
         up_version = data.get('info', {}).get('version', None)
 
-        our_version = get_version()
+        our_version = pkg_resources.require('auterion-cli')[0].version
         try:
             if version.parse(up_version) > version.parse(our_version):
                 print("  ┌──────────────────────────────────────────────────────────────────────────────────────┐")
